# update-electron-s3

> Package to apply auto-update for an electron application using s3 amazon service
                                                                        


Powered by the free and open-source [update.electronjs.org](https://update.electronjs.org) service.

Bifurcated from the project [update-electron-app](https://github.com/electron/update-electron-app).

![screenshot](screenshot.png)

## Requirements

Before using this module, make sure your Electron app meets these criteria:

- Your app runs on macOS or Windows
- Your app has a bucket for Amazon S3

## Installation

```sh
npm i update-electron-s3
```

then you will create the 'electron-builder.yml' on your main project this file will contain this content

```yml
appId: your.App.Id
publish:
   provider: s3
   bucket: "your-bucket"
```

## Usage

Drop this anywhere in your main process:

```js

import { autoUpdater } from 'electron-updater'

require('update-electron-s3')({autoUpdater})
```

That's it! Here's what happens by default:


- Your app will check for updates at startup, then every ten minutes. This interval is [configurable](#API).
- No need to wait for your app's `ready` event; the module figures that out.
- If an update is found, it will automatically be downloaded in the background.
- When an update is finished downloading, a dialog is displayed allowing the user to restart the app now or later.

You can also specify custom options:

```js
require('update-electron-s3')({
  electron,
  autoUpdater,
  updateInterval: '1 hour',
  logger: require('electron-log')
})
```

## API

### `update(options)`

Options:

- `s3` String (optional) - S3 bucket `bucket`. Defaults to your `package.json`'s `"bucket_s3"` field
- `updateInterval` String (optional) - How frequently to check for updates. Defaults to `10 minutes`. Minimum allowed interval is `5 minutes`.
- `logger` Object (optional) - A custom logger object that defines a `log` function. Defaults to `console`. See [electron-log](https://github.com/megahertz/electron-log), a module that aggregates logs from main and renderer processes into a single file.

## FAQ

#### What kinds of assets do I need to build?

For macOS, you'll need to build a `.zip` file and include it in your GitHub Release. 
Use [electron-forge] or [electron-installer-zip] to package your app as a zip.

For Windows, you'll need to build a `.exe` file and include it in your GitHub Release. 

#### Why is my app launching multiple times?

Windows apps have an update process that requires multiple application restarts.
You can use the [electron-squirrel-startup](https://github.com/mongodb-js/electron-squirrel-startup) module to improve this 
behavior.


## License

MIT

## See Also

If your app is packaged with `electron-builder`, you may not need this module. 
Builder has its own built-in mechanism for updating apps. Find out more at 
[electron.build/auto-update](https://www.electron.build/auto-update).

[electron-forge]: https://github.com/electron-userland/electron-forge
[electron-installer-zip]: https://github.com/mongodb-js/electron-installer-zip
[code signed]: https://github.com/electron/electron/blob/master/docs/tutorial/code-signing.md